/**
* @file screen-espionage-details.ts
* @copyright 2024, Firaxis Games
* @description Displays details about completed espionage actions
*/
import DiplomacyManager from '/base-standard/ui/diplomacy/diplomacy-manager.js';
import FocusManager from '/core/ui/input/focus-manager.js';
import { InputEngineEventName } from '/core/ui/input/input-support.js';
import { Navigation } from '/core/ui/input/navigation-support.js';
import Panel from '/core/ui/panel-support.js';
import { MustGetElement } from '/core/ui/utilities/utilities-dom.js';
class EspionageDetailsScreen extends Panel {
    constructor() {
        super(...arguments);
        this.engineInputListener = (inputEvent) => { this.onEngineInput(inputEvent); };
    }
    render() {
        this.Root.innerHTML = `
			<div class="w-194 relative">
				<fxs-modal-frame class="w-full espionage-details-bg">
					<div class="flex flex-col w-full h-auto pl-60 items-start">
						<fxs-header class="mb-6 font-title text-2xl text-secondary" filigree-style="small" title="LOC_DIPLOMACY_ESPIONAGE_DETAILS_HEADER"></fxs-header>
						<div id="espionage-status-container" class="flex flex-col mb-3"></div>
						<fxs-inner-frame id="espionage-details-container" class="min-h-40 mr-6 w-full p-2"></fxs-inner-frame>
					</div>
					<fxs-hslot id="espionage-details-button-container" class="flex flex-row w-full h-auto justify-around mt-10"></fxs-vslot>
				</fxs-modal-frame>
				<img class="absolute -top-16 -left-24" src="blp:dip_esp_image.png">
				<fxs-close-button class="right-2 top-1"></fxs-close-button>
			</div>
		`;
        const buttonContainer = MustGetElement("#espionage-details-button-container", this.Root);
        const acknowledgeButton = document.createElement("chooser-item");
        acknowledgeButton.classList.add("chooser-item_unlocked", "h-16", "flex", "flex-row", "w-76");
        acknowledgeButton.addEventListener("action-activate", () => { this.close(); });
        const acknowledgeIconContainer = document.createElement("div");
        acknowledgeIconContainer.classList.value = "chooser-item__icon flex self-center items-center justify-center pointer-events-none relative";
        acknowledgeButton.appendChild(acknowledgeIconContainer);
        const acknowledgeIconImage = document.createElement("div");
        acknowledgeIconImage.classList.value = "chooser-item__icon-image relative flex flex-col items-center justify-center espionage-details-acknowledge-icon";
        acknowledgeIconContainer.appendChild(acknowledgeIconImage);
        const acknowledgeString = document.createElement("div");
        acknowledgeString.classList.add("font-title", "text-lg", "mb-1", "pointer-events-none", "font-fit-shrink", "self-center", "relative", "flex-1", "p-px");
        acknowledgeString.innerHTML = Locale.compose("LOC_DIPLOMACY_ESPIONAGE_DETAILS_ACKNOWLEDGE");
        acknowledgeButton.appendChild(acknowledgeString);
        buttonContainer.appendChild(acknowledgeButton);
        const diplomacyButton = document.createElement("chooser-item");
        diplomacyButton.classList.add("chooser-item_unlocked", "h-16", "flex", "flex-row", "w-76");
        diplomacyButton.addEventListener("action-activate", () => { DiplomacyManager.raiseDiplomacyHub(DiplomacyManager.currentEspionageData?.Header.targetPlayer ? DiplomacyManager.currentEspionageData?.Header.targetPlayer : GameContext.localPlayerID); });
        const diplomacyIconContainer = document.createElement("div");
        diplomacyIconContainer.classList.value = "chooser-item__icon flex self-center items-center justify-center pointer-events-none relative";
        diplomacyButton.appendChild(diplomacyIconContainer);
        const diplomacyIconImage = document.createElement("div");
        diplomacyIconImage.classList.value = "chooser-item__icon-image relative flex flex-col items-center justify-center espionage-details-diplomacy-icon";
        diplomacyIconContainer.appendChild(diplomacyIconImage);
        const diplomacyString = document.createElement("div");
        diplomacyString.classList.add("font-title", "text-lg", "mb-1", "pointer-events-none", "font-fit-shrink", "self-center", "relative", "flex-1", "p-px");
        diplomacyString.innerHTML = Locale.compose("LOC_DIPLOMACY_OPEN_DIPLOMACY");
        diplomacyButton.appendChild(diplomacyString);
        buttonContainer.appendChild(diplomacyButton);
        const closeButton = MustGetElement("fxs-close-button", this.Root);
        closeButton.addEventListener("action-activate", () => { this.close(); });
    }
    onAttach() {
        super.onAttach();
        this.render();
        this.Root.addEventListener(InputEngineEventName, this.engineInputListener);
        this.populateEspionageDetails();
    }
    onDetach() {
        this.Root.removeEventListener(InputEngineEventName, this.engineInputListener);
    }
    onReceiveFocus() {
        const focusableElement = Navigation.getFirstFocusableElement(this.Root, { isDisableFocusAllowed: true, direction: InputNavigationAction.NONE });
        if (focusableElement) {
            FocusManager.setFocus(focusableElement);
        }
        else {
            FocusManager.setFocus(this.Root);
        }
    }
    onEngineInput(inputEvent) {
        if (inputEvent.detail.status != InputActionStatuses.FINISH) {
            return;
        }
        if (inputEvent.isCancelInput() || inputEvent.detail.name == 'sys-menu') {
            this.close();
        }
    }
    populateEspionageDetails() {
        if (!DiplomacyManager.currentEspionageData) {
            console.error("screen-espionage-details: Attempting to populate espionage details but no valid espionage data!");
            return;
        }
        
        const statusContainer = MustGetElement("#espionage-status-container", this.Root);
        const detailsContainer = MustGetElement("#espionage-details-container", this.Root);
        
        const espionageData = DiplomacyManager.currentEspionageData;
        const { Header } = espionageData;
        
        statusContainer.appendChild(this.createEspionageStatusRow(
            Header.failed ? "fs://game/dip_esp_fail_icon.png" : "fs://game/dip_esp_success_icon.png", 
            Locale.compose(Header.failed ? "LOC_DIPLOMACY_ESPIONAGE_DETAILS_FAILED" : "LOC_DIPLOMACY_ESPIONAGE_DETAILS_SUCCESS")
        ));
        
        statusContainer.appendChild(this.createEspionageStatusRow(
            Header.revealed ? "fs://game/dip_esp_reveal_icon.png" : "fs://game/dip_esp_noreveal_icon.png", 
            Locale.compose(Header.revealed ? "LOC_DIPLOMACY_ESPIONAGE_DETAILS_REVEALED" : "LOC_DIPLOMACY_ESPIONAGE_DETAILS_HIDDEN")
        ));
        
        const detailsElement = document.createElement("div");
        detailsElement.classList.value = "w-full font-body text-base font-fit-shrink";
        
        const spyPlayer = Players.get(espionageData.Header.initialPlayer);
        const targetPlayer = Players.get(espionageData.Header.targetPlayer);
        const actionName = Locale.compose(espionageData.Header.name);
        
        let detailsText;
        if (Header.failed) {
            const isTarget = Header.targetPlayer === GameContext.localPlayerID;
            const revealedKey = Header.revealed 
                ? (isTarget 
                    ? "LOC_NOTIFICATION_DIPLOMATIC_ESPIONAGE_FAILED_REVEALED_TARGET" 
                    : "LOC_NOTIFICATION_DIPLOMATIC_ESPIONAGE_FAILED_REVEALED_INITIATOR")
                : (isTarget
                    ? "LOC_NOTIFICATION_DIPLOMATIC_ESPIONAGE_FAILED_NOT_REVEALED_TARGET"
                    : "LOC_NOTIFICATION_DIPLOMATIC_ESPIONAGE_FAILED_NOT_REVEALED_INITIATOR");
            
            detailsText = `${Locale.compose("LOC_MOD_ESPIONAGE_FAILURE")}: ${actionName}. `;
            detailsText += Locale.compose(revealedKey, 
                isTarget ? Locale.compose(spyPlayer.name) : Locale.compose(targetPlayer.name)
            );
        } else {
            detailsText = espionageData.DetailsString;
        }
        
        detailsElement.innerHTML = Locale.stylize(detailsText);
        detailsContainer.appendChild(detailsElement);
    }
    
    createEspionageStatusRow(imageSource, statusString) {
        const statusrow = document.createElement("div");
        statusrow.classList.value = "flex flex-row items-center";
        const statusIcon = document.createElement("img");
        statusIcon.classList.value = "mr-2";
        statusIcon.src = imageSource;
        statusrow.appendChild(statusIcon);
        const statusStringElement = document.createElement("div");
        statusStringElement.classList.value = "font-title text-lg uppercase font-fit-shrink grow";
        statusStringElement.innerHTML = statusString;
        statusrow.appendChild(statusStringElement);
        return statusrow;
    }
}
Controls.define('screen-espionage-details', {
    createInstance: EspionageDetailsScreen,
    description: 'Espionage Details Screen.',
    styles: ['fs://game/base-standard/ui/espionage-details/screen-espionage-details.css'],
    classNames: ['screen-espionage-details'],
    attributes: []
});

//# sourceMappingURL=file:///base-standard/ui/espionage-details/screen-espionage-details.js.map
